==> cherry_flutter-0.0.1.tar.gz: example/lib/demo/action_sheet.dart <==
import 'package:cherry_flutter/cherry_flutter.dart';
import 'package:example/widgets/widgets.dart';
import 'package:flutter/material.dart';

class ActionSheetDemo extends StatelessWidget {
  const ActionSheetDemo({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(title: Text('ActionSheet Page')),
      body: SingleChildScrollView(
        padding: EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            CommonTitle(title: '默认'),
            CHButton(
              color: Colors.blue,
              content: '默认 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1'),
                  ActionSheetItem(name: '选项2', value: '2'),
                ];
                String? _result = await ActionSheet(
                  actions: actionList,
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '取消按钮'),
            CHButton(
              color: Colors.blue,
              content: '取消 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1'),
                  ActionSheetItem(name: '选项2', value: '2'),
                ];
                String? _result = await ActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '二级标题'),
            CHButton(
              color: Colors.blue,
              content: '二级标题 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1'),
                  ActionSheetItem(name: '选项2', subName: '二级标题', value: 2),
                ];
                final _result = await ActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result is int);
                print(_result is String);
              },
            ),
            CommonTitle(title: 'loading disable'),
            CHButton(
              color: Colors.blue,
              content: 'Loading Disabled',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1', loading: true),
                  ActionSheetItem(name: '选项2', value: '2', disabled: true),
                  ActionSheetItem(value: '3', loading: true),
                  ActionSheetItem(name: '选项3', value: '4'),
                ];
                String? _result = await ActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '标题'),
            CHButton(
              color: Colors.blue,
              content: '标题 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1'),
                  ActionSheetItem(name: '选项2', subName: '二级标题', value: '2'),
                ];
                String? _result = await ActionSheet(
                  actions: actionList,
                  title: '标题',
                  description: '我是标题的描述',
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            SizedBox(height: 10),
            CHButton(
              color: Colors.blue,
              content: '标题描述 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem(name: '选项1', value: '1'),
                  ActionSheetItem(name: '选项2', subName: '二级标题', value: '2'),
                ];
                String? _result = await ActionSheet(
                  actions: actionList,
                  description: '我是标题的描述',
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            SizedBox(height: 10),
            CHButton(
              color: Colors.blue,
              content: '标题描述 ActionSheet',
              onTap: () async {
                final List<ActionSheetItem> actionList = [
                  ActionSheetItem<int>(name: '选项1', value: 1),
                  ActionSheetItem<int>(name: '选项2', subName: '二级标题', value: 2),
                ];
                int? _result = await ActionSheet<int>(
                  actions: actionList,
                  customDescription: Text('标题描述',
                      style: TextStyle(
                          fontSize: 11, color: const Color(0xffAAAAAA))),
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(
                title:
                    'actionSheetItem的value为dynamic, 若要限制返回值泛型, item值和T需要保持统一, 如果不需要限制, item 的value可以任意传, 此时ActionSheet的泛型不需要限制'),
          ],
        ),
      ),
    );
  }
}

==> cherry_flutter-0.0.3.tar.gz: example/lib/demo/action_sheet.dart <==
import 'package:cherry_flutter/cherry_flutter.dart';
import 'package:example/widgets/widgets.dart';
import 'package:flutter/material.dart';

class ActionSheetDemo extends StatelessWidget {
  const ActionSheetDemo({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(title: Text('ActionSheet Page')),
      body: SingleChildScrollView(
        padding: EdgeInsets.symmetric(horizontal: 20),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            CommonTitle(title: '默认'),
            CHFButton(
              color: Colors.blue,
              content: '默认 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1'),
                  CHFActionSheetItem(name: '选项2', value: '2'),
                ];
                String? _result = await CHFActionSheet(
                  actions: actionList,
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '取消按钮'),
            CHFButton(
              color: Colors.blue,
              content: '取消 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1'),
                  CHFActionSheetItem(name: '选项2', value: '2'),
                ];
                String? _result = await CHFActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '二级标题'),
            CHFButton(
              color: Colors.blue,
              content: '二级标题 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1'),
                  CHFActionSheetItem(name: '选项2', subName: '二级标题', value: 2),
                ];
                final _result = await CHFActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result is int);
                print(_result is String);
              },
            ),
            CommonTitle(title: 'loading disable'),
            CHFButton(
              color: Colors.blue,
              content: 'Loading Disabled',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1', loading: true),
                  CHFActionSheetItem(name: '选项2', value: '2', disabled: true),
                  CHFActionSheetItem(value: '3', loading: true),
                  CHFActionSheetItem(name: '选项3', value: '4'),
                ];
                String? _result = await CHFActionSheet(
                  actions: actionList,
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(title: '标题'),
            CHFButton(
              color: Colors.blue,
              content: '标题 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1'),
                  CHFActionSheetItem(name: '选项2', subName: '二级标题', value: '2'),
                ];
                String? _result = await CHFActionSheet(
                  actions: actionList,
                  title: '标题',
                  description: '我是标题的描述',
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            SizedBox(height: 10),
            CHFButton(
              color: Colors.blue,
              content: '标题描述 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem(name: '选项1', value: '1'),
                  CHFActionSheetItem(name: '选项2', subName: '二级标题', value: '2'),
                ];
                String? _result = await CHFActionSheet(
                  actions: actionList,
                  description: '我是标题的描述',
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            SizedBox(height: 10),
            CHFButton(
              color: Colors.blue,
              content: '标题描述 ActionSheet',
              onTap: () async {
                final List<CHFActionSheetItem> actionList = [
                  CHFActionSheetItem<int>(name: '选项1', value: 1),
                  CHFActionSheetItem<int>(name: '选项2', subName: '二级标题', value: 2),
                ];
                int? _result = await CHFActionSheet<int>(
                  actions: actionList,
                  customDescription: Text('标题描述',
                      style: TextStyle(
                          fontSize: 11, color: const Color(0xffAAAAAA))),
                  cancelText: '取消',
                  roundRadius: 10,
                  background: Colors.white,
                  spacerColor: const Color(0xffF7F7F7),
                  lineColor: const Color(0xffF1F1F1),
                ).show(context);
                print(_result);
              },
            ),
            CommonTitle(
                title:
                    'actionSheetItem的value为dynamic, 若要限制返回值泛型, item值和T需要保持统一, 如果不需要限制, item 的value可以任意传, 此时ActionSheet的泛型不需要限制'),
          ],
        ),
      ),
    );
  }
}
